@@ -5,24 +5,23 @@ set -ex
 # bridge so the juju lxd provider can function. Taken from changes made
 # to cloud-init to do approximately this.
 
-# Detect LXD API extensions
-lxd_extension() {
-    lxc info | grep -q "^\- ${1}$"
-}
+VERSION=$(lxd --version)
 
-# Configure LXD networking
-if lxd_extension "network"; then
-    # LXD 2.3+ needs lxdbr0 setup via lxc.
+# LXD 2.3+ needs lxdbr0 setup via lxc.
+if dpkg --compare-versions "$VERSION" gt "2.2"; then
     if ! lxc network list | grep -q lxdbr0; then
         # Configure a known address ranges for lxdbr0.
         lxc network create lxdbr0 \
             ipv4.address=10.0.8.1/24 ipv4.nat=true \
             ipv6.address=none ipv6.nat=false
-        lxc network attach-profile lxdbr0 default eth0
     fi
-else
-    # LXD 2.2 and earlier use debconf to create and configure the network.
-    debconf-communicate << EOF
+    lxc network show lxdbr0
+    lxc config show
+    exit 0
+fi
+
+# LXD 2.2 and earlier use debconf to create and configure the network.
+debconf-communicate << EOF
 set lxd/setup-bridge true
 set lxd/bridge-domain lxd
 set lxd/bridge-name lxdbr0
@@ -36,15 +35,9 @@ set lxd/bridge-ipv4-nat true
 set lxd/bridge-ipv6 false
 EOF
 
-    rm -rf /etc/default/lxd-bridge
-    dpkg-reconfigure lxd --frontend=noninteractive
-fi
+rm -rf /etc/default/lxd-bridge
 
-# Configure LXD storage
-if lxd_extension "storage"; then
-    lxc storage create default dir
-    lxc profile device add default root disk path=/ pool=default
-fi
+dpkg-reconfigure lxd --frontend=noninteractive
 
 # Must run a command for systemd socket activation to start the service
-lxc finger
+lxc config show
